summaryrefslogtreecommitdiff
path: root/spec/ruby/library/readline/spec_helper.rb
diff options
context:
space:
mode:
Diffstat (limited to 'spec/ruby/library/readline/spec_helper.rb')
-rw-r--r--spec/ruby/library/readline/spec_helper.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/spec/ruby/library/readline/spec_helper.rb b/spec/ruby/library/readline/spec_helper.rb
index 56077c53c4..32d820f7ac 100644
--- a/spec/ruby/library/readline/spec_helper.rb
+++ b/spec/ruby/library/readline/spec_helper.rb
@@ -4,8 +4,8 @@ begin
require 'readline'
rescue LoadError
else
- # rb-readline behaves quite differently
- unless defined?(RbReadline)
+ # rb-readline and reline behave quite differently
+ unless defined?(RbReadline) or defined?(Reline)
MSpec.enable_feature :readline
end
end